aboutsummaryrefslogtreecommitdiffstats
path: root/samsung-ipc/device/galaxys2/galaxys2_loader.h
diff options
context:
space:
mode:
authorPaul Kocialkowski <contact@paulk.fr>2012-07-05 17:54:25 +0200
committerPaul Kocialkowski <contact@paulk.fr>2012-07-05 19:14:37 +0200
commit84cd42f10be74c0a60545c2035876e3beca644a3 (patch)
treeb78334b1d9ba9ce2ff6d5ac65cd4b2c6b0130bd9 /samsung-ipc/device/galaxys2/galaxys2_loader.h
parent2eea520884474f4eefcf03815d52dfaac9e03cce (diff)
downloadexternal_libsamsung-ipc-84cd42f10be74c0a60545c2035876e3beca644a3.zip
external_libsamsung-ipc-84cd42f10be74c0a60545c2035876e3beca644a3.tar.gz
external_libsamsung-ipc-84cd42f10be74c0a60545c2035876e3beca644a3.tar.bz2
XMM6260: Split code into galaxys2, maguro and xmm2620 (shared code) devices
* Moved maguro and galaxys2 loaders to proper folders * Renamed i9100 to galaxys2 and i9250 to maguro * Device-specific ops, handlers, gprs_specs and nv_data_specs on XMM2620 devices though most data/functions are still shared in xmm2620_ipc * Removed radio_parts from modemctl_io_data * Moved CRC calculate function to xmm2620_loader * Moved io_helpers functions to xmm2620_loader * Listed include headers in each file instead of using common.h * Prefixed remaining xmm2620 files Signed-off-by: Paul Kocialkowski <contact@paulk.fr>
Diffstat (limited to 'samsung-ipc/device/galaxys2/galaxys2_loader.h')
-rw-r--r--samsung-ipc/device/galaxys2/galaxys2_loader.h21
1 files changed, 14 insertions, 7 deletions
diff --git a/samsung-ipc/device/galaxys2/galaxys2_loader.h b/samsung-ipc/device/galaxys2/galaxys2_loader.h
index 06dadd7..3bc6924 100644
--- a/samsung-ipc/device/galaxys2/galaxys2_loader.h
+++ b/samsung-ipc/device/galaxys2/galaxys2_loader.h
@@ -1,6 +1,7 @@
/*
* Firmware loader for Samsung I9100 and I9250
* Copyright (C) 2012 Alexander Tarasikov <alexander.tarasikov@gmail.com>
+ * Copyright (C) 2012 Paul Kocialkowski <contact@paulk.fr>
*
* based on the incomplete C++ implementation which is
* Copyright (C) 2012 Sergey Gridasov <grindars@gmail.com>
@@ -19,8 +20,12 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __FWLOADER_I9100_IPC_H__
-#define __FWLOADER_I9100_IPC_H__
+#include <stdbool.h>
+#include <stdint.h>
+#include <stdlib.h>
+
+#ifndef __GALAXYS2_LOADER_H__
+#define __GALAXYS2_LOADER_H__
#define RADIO_IMAGE "/dev/block/mmcblk0p8"
#define I9100_EHCI_PATH "/sys/devices/platform/s5p-ehci/ehci_power"
@@ -48,28 +53,30 @@
#define FW_LOAD_ADDR 0x60300000
#define NVDATA_LOAD_ADDR 0x60e80000
-struct i9100_boot_cmd_desc {
+struct galaxys2_boot_cmd_desc {
unsigned code;
size_t data_size;
bool need_ack;
};
-struct i9100_psi_header {
+struct galaxys2_psi_header {
uint8_t magic;
uint16_t length;
uint8_t padding;
} __attribute__((packed));
-struct i9100_boot_info {
+struct galaxys2_boot_info {
uint8_t data[76];
} __attribute__((packed));
-struct i9100_boot_cmd {
+struct galaxys2_boot_cmd {
uint16_t check;
uint16_t cmd;
uint32_t data_size;
} __attribute__((packed));
+int galaxys2_modem_bootstrap(struct ipc_client *client);
+
#endif
// vim:ts=4:sw=4:expandtab
@@ -1,6 +1,7 @@
/*
- * Firmware loader for Samsung I9100 and I9250
+ * Firmware loader for Samsung I9100 (galaxys2)
* Copyright (C) 2012 Alexander Tarasikov <alexander.tarasikov@gmail.com>